/***************************************************************************
Copyright (c) 2016 Benedikt Stockebrand
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
***************************************************************************/


//**************************************************************************
//****************  Beginning of hardware specific sections  ***************
//**************************************************************************

//******  ATmega 328P  ************************
#if defined(__AVR_ATmega328P__)

// Hardware specific header file
#include <avr/io.h>

// Initialize MCU
#define init_mcu()



// Output is to PORTB
#define init_output()        (DDRB = 0xff)
#define update_output(value) (PORTB = value)

// Input is from PIND:7
#define init_input()
#define read_input()         (PIND & (1<<7))





//******  MSP430 G2553  ***********************
#elif defined(__MSP430G2553__)

// Hardware specific header file
#include <msp430.h>

// Initialize MCU
#define init_mcu()           (WDTCTL = WDTPW | WDTHOLD)



// Output is to PORT1
#define init_output()        (P1DIR = 0xff)
#define update_output(value) (P1OUT = value)

// Input is from P2:2
#define init_input()
#define read_input()         (P2IN & (1<<2))





//******  PIC16F887  **************************
#elif defined(__PIC16F887__)

// Hardware specific header file
#include <pic14/pic16f887.h>

// Initialize MCU
unsigned int __at _CONFIG1 configWord1=0x2FF4;
unsigned int __at _CONFIG2 configWord2=0x3fff;
#define init_mcu()

// Output is to PORTD
#define init_output()        (TRISD = 0x00)
#define update_output(value) (PORTD = value)

// Input is from PORTB:0
// NB: This is by default an analog input; must be explicitly
//     configured as a digital GPIO pin by setting ANSELH:4 = 0!
#define init_input()         (ANSELH &= ~(1<<4))
#define read_input()         (PORTB & (1<<0))



//******  Final catch-all  ********************
#else
#error "Hardware plattform not specified"
//*********************************************
//***  End of hardware specific sections  *****<
//*********************************************
#endif

